==> TuxGuitar-0.2.tar.gz: TuxGuitar-0.2/src/org/herac/tuxguitar/gui/tab/DurationCoords.java <==
/*
 * Created on 29-nov-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.tab;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class DurationCoords {
    private boolean[] usedStrings;
    private int x1;
    private int x2;    
    private int eighthY;
    private int sixteenthY;
    private int thirtySecondY;
    private int sixtyFourthY; 
    
    public DurationCoords(){        
    }
        
    public int getEighthY() {
        return eighthY;
    }
    public void setEighthY(int eighthY) {
        this.eighthY = eighthY;
    }
    public int getSixteenthY() {
        return sixteenthY;
    }
    public void setSixteenthY(int sixteenthY) {
        this.sixteenthY = sixteenthY;
    }
    public int getSixtyFourthY() {
        return sixtyFourthY;
    }
    public void setSixtyFourthY(int sixtyFourthY) {
        this.sixtyFourthY = sixtyFourthY;
    }
    public int getThirtySecondY() {
        return thirtySecondY;
    }
    public void setThirtySecondY(int thirtySecondY) {
        this.thirtySecondY = thirtySecondY;
    }
    public int getX1() {
        return x1;
    }
    public void setX1(int x1) {
        this.x1 = x1;
    }
    public int getX2() {
        return x2;
    }
    public void setX2(int x2) {
        this.x2 = x2;
    }          
    public boolean[] getUsedStrings() {
        return usedStrings;
    }
    public void setUsedStrings(boolean[] usedStrings) {
        this.usedStrings = usedStrings;
    }
}

==> TuxGuitar-0.3.tar.gz: TuxGuitar-0.3/src/org/herac/tuxguitar/gui/tab/DurationCoords.java <==
/*
 * Created on 29-nov-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.tab;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class DurationCoords {
    private boolean[] usedStrings;
    //private int x1;
    //private int x2;    
    private NoteCoords note1;
    private NoteCoords note2;       
    private int eighthY;
    private int sixteenthY;
    private int thirtySecondY;
    private int sixtyFourthY; 
    
    public DurationCoords(){        
    }
        
    public int getEighthY() {
        return eighthY;
    }
    public void setEighthY(int eighthY) {
        this.eighthY = eighthY;
    }
    public int getSixteenthY() {
        return sixteenthY;
    }
    public void setSixteenthY(int sixteenthY) {
        this.sixteenthY = sixteenthY;
    }
    public int getSixtyFourthY() {
        return sixtyFourthY;
    }
    public void setSixtyFourthY(int sixtyFourthY) {
        this.sixtyFourthY = sixtyFourthY;
    }
    public int getThirtySecondY() {
        return thirtySecondY;
    }
    public void setThirtySecondY(int thirtySecondY) {
        this.thirtySecondY = thirtySecondY;
    }

    public boolean[] getUsedStrings() {
        return usedStrings;
    }
    public void setUsedStrings(boolean[] usedStrings) {
        this.usedStrings = usedStrings;
    }
    
    public NoteCoords getNote1() {
        return note1;
    }
    public void setNote1(NoteCoords note1) {
        this.note1 = note1;
    }
    public NoteCoords getNote2() {
        return note2;
    }
    public void setNote2(NoteCoords note2) {
        this.note2 = note2;
    }
}
